
.. toctree::

.. _rt_tuning_yaml: 

**************************
ROSCO_Toolbox tuning .yaml
**************************
Definition of inputs for ROSCO tuning procedure


The inputs to the rosco tuning yaml are defined in the rosco toolbox_schema.yaml file, which is located in the :code:`rosco/toolbox/inputs` folder.
The following is automatically generated from that file:

.. raw:: html
   :file: ../_static/toolbox_doc.html
